@@ -508,14 +508,6 @@ class transformCtxt(transformCtxtBase):
     # transformCtxt functions from module extra
     #
 
-    def debug(self, node, inst, comp):
-        """Process an debug node"""
-        if node == None: node__o = None
-        else: node__o = node._o
-        if inst == None: inst__o = None
-        else: inst__o = inst._o
-        libxsltmod.xsltDebug(self._o, node__o, inst__o, comp)
-
     def registerExtras(self):
         """Registers the built-in extensions. This function is
            deprecated, use xsltRegisterAllExtras instead."""
@@ -526,7 +518,7 @@ class transformCtxt(transformCtxtBase):
     #
 
     def findElemSpaceHandling(self, node):
-        """Find strip-space or preserve-space informations for an
+        """Find strip-space or preserve-space information for an
            element respect the import precedence or the wildcards"""
         if node == None: node__o = None
         else: node__o = node._o
@@ -871,8 +863,8 @@ class transformCtxt(transformCtxtBase):
     def profileInformation(self):
         """This function should be called after the transformation
           completed to extract template processing profiling
-          informations if availble. The informations are returned as
-          an XML document tree like <?xml version="1.0"?> <profile>
+          information if available. The information is returned as an
+          XML document tree like <?xml version="1.0"?> <profile>
           <template rank="1" match="*" name="" mode="" calls="6"
           time="48" average="8"/> <template rank="2"
           match="item2|item3" name="" mode="" calls="10" time="30"
@@ -885,7 +877,7 @@ class transformCtxt(transformCtxtBase):
         return libxml2.xmlDoc(_obj=ret)
 
     def saveProfiling(self, output):
-        """Save the profiling informations on @output"""
+        """Save the profiling information on @output"""
         libxsltmod.xsltSaveProfiling(self._o, output)
 
     def setCtxtParseOptions(self, options):
